import {
  IconWarning,
  IconIgnore,
  IconSend,
  IconHandle,
  IconArchive,
  IconDepartment,
  IconEmergency,
  IconHighway,
  IconNavigation,
  IconRailway,
  IconTransportation,
  IconCar,
  IconReport,
  IconRoster,
  IconStorehouse,
  IconTeam,
} from '@/constants/icon';
import { useCommonStore } from '@/store';
import { computed } from 'vue-demi';

const INCIDENT_ICON = {
  1: IconWarning,
  2: IconSend,
  3: IconHandle,
  4: IconArchive,
  5: IconIgnore,
};
const PLAN_ICON = {
  1: IconDepartment,
  2: IconEmergency,
  3: IconTransportation,
  4: IconNavigation,
  5: IconRailway,
  6: IconHighway,
};

const RESOURCE_ICON = {
  1: IconStorehouse,
  2: IconTeam,
  3: IconCar,
};

const DUTY_ICON = {
  1: IconReport,
  2: IconRoster,
};

export default () => {
  const store = useCommonStore();

  const MENUS_INCIDENT = computed(() => {
    const items = store.globalDict['zhdd_incident_status']?.map(
      (item, idx) => ({
        name: item.dictLabel,
        path: `/incident-management/status/${item.dictValue}`,
        icon: INCIDENT_ICON[
          item.dictValue as unknown as keyof typeof INCIDENT_ICON
        ],
      }),
    );
    return {
      title: {
        name: '事件状态',
        path: '/incident-management/status' as const,
      },
      items,
    };
  });

  const MENUS_EMERGENCY_PLAN = computed(() => {
    const items = store.globalDict['zhdd_org_upload']?.map((item) => ({
      name: item.dictLabel,
      path: `/emergency-plan/department/${item.dictValue}`,
      icon: PLAN_ICON[item.dictValue as unknown as keyof typeof PLAN_ICON],
    }));
    return {
      title: { name: '应急预案', path: null },
      items,
    };
  });

  const MENUS_EMERGENCY_RESOURCES = computed(() => {
    const items = store.globalDict['zhdd_resource']?.map((item) => ({
      name: item.dictLabel,
      path: `/emergency-resources/resources/${item.dictValue}`,
      icon: RESOURCE_ICON[
        item.dictValue as unknown as keyof typeof RESOURCE_ICON
      ],
    }));
    return {
      title: { name: '应急资源', path: null },
      items,
    };
  });

  return {
    MENUS_INCIDENT,
    MENUS_EMERGENCY_PLAN,
    MENUS_EMERGENCY_RESOURCES,
  };
};
