import {
  getReportList,
  GetReportListParams,
  getRosterList,
  postReporItem,
  putReporItem,
  putRosterItem,
  ReporItemParams,
  ReportListResponse,
  RosterItem,
} from '@/api/duty';
import { ElMessage } from 'element-plus';
import { defineStore } from 'pinia';

export interface DutyStateType {
  loading: boolean;
  reports: ReportListResponse;
  rosters: RosterItem[];
}

export interface DutyActionsType {
  toggleLoading(): void;
  getReportList(params: GetReportListParams): void;
  postReporItem(params: ReporItemParams): Promise<boolean>;
  putReporItem(params: ReporItemParams): Promise<boolean>;
  getRosterList(): void;
  putRosterItem(params: RosterItem): void;
}

export default defineStore<'duty', DutyStateType, {}, DutyActionsType>('duty', {
  state: () => ({
    reports: {
      rows: [],
      total: 0,
    },
    rosters: [],
    loading: false,
  }),
  actions: {
    toggleLoading() {
      this.loading = !this.loading;
    },
    async getReportList(params) {
      try {
        this.toggleLoading();
        this.reports = await getReportList(params);
      } finally {
        this.toggleLoading();
      }
    },
    async postReporItem(params) {
      try {
        this.toggleLoading();
        await postReporItem(params);
        ElMessage.success({ message: '新增成功' });
        return true;
      } finally {
        this.toggleLoading();
      }
    },
    async putReporItem(params) {
      try {
        this.toggleLoading();
        const {} = await putReporItem(params);
        if (params.status === 1) {
          ElMessage.success({ message: '保存成功' });
        }
        if (params.status === 2) {
          ElMessage.success({ message: '提交成功' });
        }
        return true;
      } finally {
        this.toggleLoading();
      }
    },
    async getRosterList() {
      try {
        this.toggleLoading();
        const { data } = await getRosterList();
        this.rosters = data;
      } finally {
        this.toggleLoading();
      }
    },

    async putRosterItem(params) {
      try {
        this.toggleLoading();
        await putRosterItem(params);
        ElMessage.success({ message: '编辑成功' });
        return true;
      } finally {
        this.toggleLoading();
      }
    },
  },
});
