import { Canceler } from 'axios';
import { defineStore } from 'pinia';

import { getTicket } from '@/service/login';

export interface MainStateType {
  cancelReqToken: Canceler[];
  loading: boolean,
}

export interface MainActionsType {
  pushReqToken(cancelToken: Canceler): void;
  clearReqToken(): void;
  gotohelp(sign:string):void;
  toggleLoading(): void;
}

export default defineStore<'main', MainStateType, {}, MainActionsType>('main', {
  state: () => ({
    cancelReqToken: [],
    loading: false,
  }),
  actions: {
    toggleLoading() {
      this.loading = !this.loading;
    },
    pushReqToken(cancelToken) {
      this.cancelReqToken.push(cancelToken);
    },
    clearReqToken() {
      this.cancelReqToken.forEach((cancel) => {
        cancel('axios cancel by router change');
      });
      this.cancelReqToken = [];
    },
    gotohelp(sign:string){
      this.toggleLoading();
      getTicket().then((res)=>{

        this.toggleLoading();
        const urlc = `${
          import.meta.env.VITE_HELP_BASE as string
        }sign=${sign}&ticket=${res.data}&isRoute==1`;
        window.location.href = urlc;

      }).catch(eee=>{
        this.toggleLoading();
      })
    }
  },
});
