import {
  defineComponent,
  ref,
  reactive,
  watch,
  watchEffect,
  onMounted,
  computed,
  onUnmounted,
} from 'vue';


import { useRouter, useRoute } from 'vue-router';
import { useCommonStore, useIncidentStore, useMainStore } from '@/store';
import useMarkerStore from '@/store/useMarkerStore';
import {
  DropdownItemOption,
  NavBar,
  DropdownMenu,
  DropdownItem,
  Icon,
  PullRefresh,
  List,
} from 'vant';
import './index.scss';
/** @ts-ignore */
import icon_type from '@/assets/icons/incident/type@2x.png';
/** @ts-ignore */
import icon_source from '@/assets/icons/incident/source@2x.png';
/** @ts-ignore */
import icon_place from '@/assets/icons/incident/place@2x.png';
/** @ts-ignore */
import icon_grade from '@/assets/icons/incident/grade@2x.png';

import { IncidentItem } from '@/api/incident';

const baseIncidentTypeOptions: DropdownItemOption[] = [
  { text: '事件类型', value: '' },
];
const baseIncidentLevelOptions: DropdownItemOption[] = [
  { text: '事件等级', value: '' },
];

export default defineComponent({
  name: 'Home',
  setup() {
    const refreshLoading = ref(false);
    const listLoading = ref(false);
    const listFinished = ref(false);

    const router = useRouter();
    const route = useRoute();
    const store = useIncidentStore();
    const commonStore = useCommonStore();
    const incidentType = ref('');
    const incidentLevel = ref('');
    const incidentTypeOptions = computed(() =>
      baseIncidentTypeOptions.concat(
        commonStore.globalDict['zhdd_incident_type']?.map(
          (o) =>
            ({
              text: o.dictLabel,
              value: o.dictValue,
            } ?? []),
        ) as DropdownItemOption[],
      ),
    );
    const incidentLevelOptions = computed(() =>
      baseIncidentLevelOptions.concat(
        commonStore.globalDict['zhdd_incident_level']?.map(
          (o) =>
            ({
              text: o.dictLabel,
              value: o.dictValue,
            } ?? []),
        ) as DropdownItemOption[],
      ),
    );

    const list = ref<IncidentItem[]>([]);

    const pageNum = ref(1);

    const handleRefresh = async () => {
      listFinished.value = false;
      pageNum.value = 1;
      listLoading.value = true;
      handleLoad();
    };
    const handleLoad = async () => {
      if (refreshLoading.value) {
        list.value = [];
        refreshLoading.value = false;
      }
      if (pageNum.value == 1) { 
        list.value = [];
      }
        await store.getIncidentList({
          type: incidentType.value,
          level: incidentLevel.value,
          querySource: "app",
          // status: '3',
          pageNum: (pageNum.value ++),
          pageSize: 10,
        });
      // if (store.)
      
      list.value.push(...(store.incidents.rows ?? []));
      if (list.value.length >= (store.incidents.total ?? 0)) {
        listFinished.value = true;
      }
      listLoading.value = false;
    };

    const handleLinkDetail = (id: string) => {
      router.push(`/status/3/detail?id=${id}`);
    };

    watch(
      [() => incidentLevel.value, () => incidentType.value],
      ([nextLevel, nextType], [preLevel, preType]) => {
        console.log('next', nextLevel, nextType);
        console.log('pre', preLevel, preType);
       handleRefresh();
      },
    );

    onMounted(() => {
      commonStore.getGlobalDict('zhdd_incident_level');
      commonStore.getGlobalDict('zhdd_incident_type');
       commonStore.getGlobalDict('zhdd_incident_source');
      // store.getIncidentList({
      //   pageNum: 1,
      //   // status: '3',
      //   pageSize: 10,
      // });
       handleRefresh();
    });
    onUnmounted(() => {});

    return () => (
      <div class="home-container">
        <NavBar
          title="应急处置"
          left-arrow
          fixed
          placeholder={true}
          onClick-left={() => {
            try {
              uni.navigateBack();
            
              
            } catch (E) {
              
            }
          }}
          onClick-right={() =>{
            useMainStore().gotohelp(`${(import.meta.env.VITE_HELP_EVENT_LIST as string)}`);
          }
          }
          v-slots={{ right: () => <Icon size="18" name="question-o" />  }}
          style={{ zIndex: 2 }}
        />
        <div
          style={{
            position: 'fixed',
            zIndex: 1,
            width: '100%',
            display: 'none',
          }}>
          <DropdownMenu>
            <DropdownItem
              v-model={incidentType.value}
              options={incidentTypeOptions.value}></DropdownItem>
            <DropdownItem
              v-model={incidentLevel.value}
              options={incidentLevelOptions.value}></DropdownItem>
          </DropdownMenu>
        </div>
        <PullRefresh
          onRefresh={handleRefresh}
          v-model={refreshLoading.value}
          successText="刷新成功"
          style="margin-top: 10px;">
          <div class="home-content">
            <List
              v-model:loading={listLoading.value}
              finished={listFinished.value}
              finished-text="没有更多了"
              onLoad={handleLoad}>
              {list.value?.map((item) => (
                <div
                  class="incident-item"
                  key={item.id}
                  onClick={() => {
                    item.id && handleLinkDetail(item.id);
                  }}>
                  <div class="title">
                    {item.name}
                    <div class="title-time">{item.createTime}</div>
                  </div>
                  <p>
                    <img src={icon_type} />
                    事件类型：
                    {
                      commonStore.globalDict['zhdd_incident_type']?.find(
                        (o) => o.dictValue.toString() === item.type?.toString(),
                      )?.dictLabel
                    }
                  </p>
                  <p>
                    <img src={icon_grade} />
                    事件等级：
                    {
                      commonStore.globalDict['zhdd_incident_level']?.find(
                        (o) =>
                          o.dictValue.toString() === item.level?.toString(),
                      )?.dictLabel
                    }
                  </p>
                  {/* <p>事件时间：{item.createTime}</p> */}
                  <p>
                    <img src={icon_place} />
                    地点：{item.addr}
                  </p>
                  <p>
                    <img src={icon_source} />
                    事件来源：
                    {commonStore.globalDict['zhdd_incident_source']?.find(
                      (i) =>
                        i.dictValue?.toString() === item.source?.toString(),
                    )?.dictLabel ?? '-'}
                  </p>
                </div>
              ))}
            </List>
          </div>
        </PullRefresh>
      </div>
    );
  },
});
